window.mmp.cookies.functions = {
  helpers: {
    enableSection(sectionName) {
      const section = window.mmp.cookies.sections[sectionName];
      if (section && section.functions && Object.keys(section.functions).length > 0) {
        Object.values(section.functions).forEach(el => {
          el();
        });
      }
    },

    checkAndSetCategory(category, enableFunction) {
      const BreakException = {};

      try {
        Object.keys(category.names).forEach(item => {;

          // Simple
          category.names[item].forEach(val => {
            if (window.mmp.cookies.functions.isCookieEnabled(val)) {
              enableFunction.call(this);
              throw BreakException;
            }
          });

          // Arrays
          category.names[item].forEach((val) => {
            const cookieValues = window.mmp.cookies.functions.getCookie(val.name);

            const parts = cookieValues.split(val.separator);
            const cookieValuesArray = {};

            for (const part of parts) {
              const [key, value] = part.split(':');
              cookieValuesArray[key] = value;
            }

            if (window.mmp.cookies.functions.isCookieEnabled(cookieValuesArray[val.key])) {
              enableFunction.call(this);
              throw BreakException;
            }
          });
        });
      } catch (e) {
        if (e !== BreakException) {
          throw e;
        }
      }
    },
  },

  enableFunctional() {
    window.mmp.cookies.functions.helpers.enableSection('functional');
  },

  enableAnalytical() {
    window.mmp.cookies.functions.helpers.enableSection('analytical');
  },

  enableAdvertisement() {
    window.mmp.cookies.functions.helpers.enableSection('advertisement');
  },

  checkAndSetFunctional() {
    window.mmp.cookies.functions.helpers.checkAndSetCategory(window.mmp.cookies.sections.functional, this.enableFunctional);
  },

  checkAndSetAnalytical() {
    window.mmp.cookies.functions.helpers.checkAndSetCategory(window.mmp.cookies.sections.analytical, this.enableAnalytical);
  },

  checkAndSetAdvertisement() {
    window.mmp.cookies.functions.helpers.checkAndSetCategory(window.mmp.cookies.sections.advertisement, this.enableAdvertisement);
  },

  checkAndSetCookies() {
    setTimeout(() => {
      this.checkAndSetFunctional();
      this.checkAndSetAnalytical();
      this.checkAndSetAdvertisement();
    }, 500);
  },

  isCookieEnabled(name) {
    const item = window.mmp.cookies.functions.getCookie(name);

    return window.mmp.cookies.functions.isEnabled(item);
  },

  isEnabled(cookieValue) {
    const positiveOptions = ["yes", "true", true, 1, "1", "allow"];

    if (cookieValue !== "") {
      return positiveOptions.includes(cookieValue);
    } else {
      return false;
    }
  },

  getCookie(cname) {
    const name = cname + "=";
    const decodedCookie = decodeURIComponent(document.cookie);
    const ca = decodedCookie.split(";");

    for (let i = 0; i < ca.length; i++) {
      let c = ca[i];
      while (c.charAt(0) === " ") {
        c = c.substring(1);
      }
      if (c.indexOf(name) === 0) {
        return c.substring(name.length, c.length);
      }
    }

    return "";
  }
};

// Check on cookies change
document.addEventListener('DOMContentLoaded', () => {
  const btns = document.querySelectorAll('#wt-cli-privacy-save-btn, #wt-cli-accept-all-btn, [data-cky-tag="accept-button"], [data-cky-tag="detail-save-button"], [data-cky-tag="detail-accept-button"]');

  btns.forEach(btn => {
    btn.addEventListener('click', () => {
      window.mmp.cookies.functions.checkAndSetCookies();
    });
  });
});

// Complianz plugin
document.addEventListener('cmplz_enable_category', consentData => {
  setTimeout(() => {
    const {category} = consentData.detail;
    if (category === 'statistics') {
      window.mmp.cookies.functions.checkAndSetAnalytical();
    } else if (category === 'marketing') {
      window.mmp.cookies.functions.checkAndSetAdvertisement();
    } else if (category === 'functional') {
      window.mmp.cookies.functions.checkAndSetFunctional();
    }
  }, 500);
});
