<?php

namespace Mergado\Service\External\Sklik;

use Mergado\Service\CookieService;
use Mergado\Traits\SingletonTrait;
use Mergado\Utils\TemplateLoader;

class SklikServiceIntegration
{
    use SingletonTrait;

    /**
     * @var SklikService
     */
    private $sklikService;

    /**
     * @var CookieService
     */
    private $cookieService;

    public function __construct()
    {
        $this->sklikService = SklikService::getInstance();
        $this->cookieService = CookieService::getInstance();
    }

    public function conversion($orderId): void
    {
        $conversionValue = $this->sklikService->getConversionValue();

        if ($this->sklikService->isConversionActive()) {
            if ($conversionValue === '') {
                $order = wc_get_order($orderId);

                if ($this->sklikService->isConversionWithVat()) {
                    $conversionValue = number_format((float)$order->get_total() - $order->get_shipping_total() - $order->get_shipping_tax(), wc_get_price_decimals(), '.', '');
                } else {
                    //Price of items
                    $conversionValue = number_format((float)$order->get_total() - $order->get_total_tax() - $order->get_shipping_total(), wc_get_price_decimals(), '.', '');
                }
            }

            echo TemplateLoader::getTemplate(__DIR__ . '/templates/conversion.php', [
                'conversionId' => $this->sklikService->getConversionCode(),
                'conversionValue' => $conversionValue,
                'consent' => (int)$this->cookieService->advertisementEnabled()
            ]);
        }
    }

    public function retargeting(): void
    {
        if ($this->sklikService->isRetargetingActive()) {

            echo TemplateLoader::getTemplate(__DIR__ . '/templates/retargeting.php', [
                'retargetingId' => $this->sklikService->getRetargetingId(),
                'consent' => (int)$this->cookieService->advertisementEnabled()
            ]);
        }
    }
}
